@@ -22,6 +22,8 @@
 #ifndef GNU_gama_localnetwork_adjustment_results__gnugamalocalnetworkadjres_h
 #define GNU_gama_localnetwork_adjustment_results__gnugamalocalnetworkadjres_h
 
+#include <gnu_gama/xml/localnetwork_adjustment_results_data.h>
+
 #include <utility>
 #include <stack>
 #include <string>
@@ -34,150 +36,14 @@
 namespace GNU_gama
 {
   class LocalNetworkAdjustmentResults
+    : public LocalNetworkAdjustmentResultsData
+
   {
   public:
 
-    LocalNetworkAdjustmentResults() { init(); }
-
     void read_xml (std::istream&) throw(Exception::parser);
     void read_html(std::istream&) throw(Exception::parser);
 
-    bool gons;
-    std::string description;
-
-    struct
-    {
-      std::string gama_local_version;
-      std::string gama_local_algorithm;
-      std::string gama_local_compiler;
-      std::string epoch;
-      std::string axes_xy;
-      std::string angles;
-
-    } network_general_parameters;
-
-    struct count
-    {
-      int xyz, xy, z;
-    };
-
-    struct
-    {
-      count adjusted;
-      count constrained;
-      count fixed;
-
-    } coordinates_summary;
-
-    struct
-    {
-      int distances;
-      int directions;
-      int angles;
-      int xyz_coords;
-      int h_diffs;
-      int z_angles;
-      int s_dists;
-      int vectors;
-      int azimuths;
-
-    } observations_summary;
-
-    struct
-    {
-      int    equations;
-      int    unknowns;
-      int    degrees_of_freedom;
-      int    defect;
-      double sum_of_squares;
-      bool   connected_network;
-
-    } project_equations;
-
-    struct
-    {
-      double apriori;
-      double aposteriori;
-      bool   using_aposteriori;
-      double probability;
-      double ratio;
-      double lower;
-      double upper;
-      bool   passed;
-      double confidence_scale;
-
-    } standard_deviation;
-
-    struct Point
-    {
-      std::string id;
-      double x, y, z;
-
-      bool   hxy, hz;             // point has   x, y, z
-      bool   cxy, cz;             // constrained x, y, z
-      int    indx, indy, indz;    // adjustment indexes
-
-      void clear()
-      {
-        x=y=z=0;
-        hxy=hz=cxy=cz=false;
-        indx=indy=indz=0;
-      }
-    };
-
-    typedef std::vector<Point> PointList;
-    PointList  fixed_points, approximate_points, adjusted_points;
-
-    struct Orientation
-    {
-      std::string id;
-      double      approx;
-      double      adj;
-      int         index;          // adjustment index
-    };
-
-    typedef std::vector<Orientation> OrientationList;
-    OrientationList orientations;
-
-    CovMat<> cov;
-
-    std::vector<int> original_index; // original indexes from the adjustment
-
-    struct Observation
-    {
-      std::string xml_tag;
-      std::string from;
-      std::string to;
-      std::string left;         // used in angle observation
-      std::string right;        //  ....   angle   ....
-
-      double obs;               // observed value
-      double adj;               // adjusted
-      double stdev;             // standard deviation of adj. value
-      double qrr;               // weight coefficient of the residual
-      double f;
-
-      double      std_residual; // standardized residual
-      std::string err_obs;      // estimate of observed value error
-      std::string err_adj;      //  ....       adjusted  ....
-
-      void clear()
-      {
-        obs = adj = stdev = qrr = f = std_residual = 0;
-        xml_tag     .clear();
-        from        .clear();
-        to          .clear();
-        left        .clear();
-        right       .clear();
-        err_obs     .clear();
-        err_adj     .clear();
-      }
-
-      double residual() const throw();
-    };
-
-    typedef std::vector<Observation> ObservationList;
-    ObservationList  obslist;
 
   private:
 
@@ -256,6 +122,10 @@ namespace GNU_gama
           s_count_z_end,
           s_description,
           s_description_end,
+          s_error_xml,
+          s_error_xml_end,
+          s_error_xml_description,
+          s_error_xml_line_number,
           s_network_general_parameters,
           s_network_general_parameters_end,
           s_gama_local_adjustment,
@@ -429,6 +299,7 @@ namespace GNU_gama
           t_dy,
           t_dz,
           t_equations,
+          t_error_xml,
           t_err_adj,
           t_err_obs,
           t_f,
@@ -442,6 +313,7 @@ namespace GNU_gama
           t_id,
           t_ind,
           t_left,
+          t_line_number,
           t_lower,
           t_network_general_parameters,
           t_network_processing_summary,
@@ -525,6 +397,9 @@ namespace GNU_gama
       void observations_summary(bool);
       void distances(bool);
       void directions(bool);
+      void error_xml(bool);
+      void error_xml_description(bool);
+      void error_xml_line_number(bool);
       void angles(bool);
       void xyz_coords(bool);
       void id(bool);
